@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2018-10-12'; # DATE
-our $VERSION = '0.864'; # VERSION
+our $DATE = '2019-04-08'; # DATE
+our $VERSION = '0.865'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -28,6 +28,7 @@ sub BUILD {
         'version',
         'description',
         'functions',
+        'methods',
         'links',
     ];
     $self->{_pa} //= do {
@@ -113,9 +114,14 @@ sub gen_doc_section_functions {
                 meta=>$meta,
                 url=> ($self->{url}//'') . $furi,
             );
+        $dres->{function_metas}{$furi} = $meta;
     }
 }
 
+sub gen_doc_section_methods {
+    # already done by gen_doc_section_functions
+}
+
 sub gen_doc_section_links {
 }
 
@@ -134,7 +140,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.864 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2018-10-12.
+This document describes version 0.865 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2019-04-08.
 
 =for Pod::Coverage .+
 
@@ -160,7 +166,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
